module StrobeGenerator(
  input  Clock,
  input  Reset,
  output Strobe
);

  parameter  Frequency_Hz = 10000000;
  parameter  Period_us    = 1;
  
  localparam PeriodCycles = Frequency_Hz / 1000000 * Period_us;
  localparam PeriodWidth  = $clog2(PeriodCycles + 1);
  
  reg [PeriodWidth-1:0] Counter = 0;
  
  always @(posedge Clock, negedge Reset)
    if(!Reset)
      Counter <= 0;
    else if(Counter == PeriodCycles - 1)
      Counter <= 0;
    else
      Counter <= Counter + 1'b1;
  
  assign Strobe = (Counter == PeriodCycles - 1);
  
endmodule
